==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pt-BR/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Ativo',
    'allow'  				=> 'Permitir',
    'checkedout'  			=> 'Ativos',
    'created_at' 			=> 'Criado',
    'createuser' 			=> 'Criar Usuário',
    'deny'  				=> 'Negar',
    'email'      			=> 'E-mail',
    'employee_num'      	=> 'Nº do Funcionário',
    'first_name' 			=> 'Primeiro Nome',
    'groupnotes'			=> 'Selecione um grupo para atribuir ao usuário, lembre-se que um usuário tem todas as permissões do grupo que ele está atribuído.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Herdar',
    'job' 					=> 'Cargo',
    'last_login'  			=> 'Último Login',
    'last_name'  			=> 'Último Nome',
    'location'  			=> 'Local',
    'lock_passwords'		=> 'Detalhes de login não podem ser alterados nesta instalação.',
    'manager' 				=> 'Gerenciador',
    'managed_locations'     => 'Gerenciar locações',
    'name' 					=> 'Nome',
    'notes'                 => 'Notas',
    'password_confirm' 		=> 'Confirmar Senha',
    'password' 				=> 'Senha',
    'phone'  				=> 'Telefone',
    'show_current'          => 'Mostrar Usuários Atuais',
    'show_deleted'          => 'Mostrar Usuários Excluídos',
    'title' 				=> 'Título',
	'to_restore_them'		=> 'para restaurar ele(a).',
    'updateuser' 			=> 'Atualizar Usuário',
    'username' 				=> 'Usuário',
	'user_deleted_text' 	=> 'Este usuário foi marcado como deletado.',
    'username_note' 		=> '(Istó é usado somente para conexão do Active Directory, não para login.)',
    'cloneuser'             => 'Clonar Usuário',
    'viewusers' 			=> 'Ver Usuários',
);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/pt-BR/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Ativo',
    'allow'  				=> 'Permitir',
    'checkedout'  			=> 'Ativos',
    'created_at' 			=> 'Criado',
    'createuser' 			=> 'Criar Usuário',
    'deny'  				=> 'Negar',
    'email'      			=> 'E-mail',
    'employee_num'      	=> 'Nº do Funcionário',
    'first_name' 			=> 'Primeiro Nome',
    'groupnotes'			=> 'Selecione um grupo para atribuir ao usuário, lembre-se que um usuário tem as permissões do grupo que ele está atribuído. Use ctrl+click (ou cmd+clique no MacOS) para desmarcar os grupos.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Herdar',
    'job' 					=> 'Cargo',
    'last_login'  			=> 'Último Login',
    'last_name'  			=> 'Último Nome',
    'location'  			=> 'Local',
    'lock_passwords'		=> 'Detalhes de login não podem ser alterados nesta instalação.',
    'manager' 				=> 'Gerente',
    'managed_locations'     => 'Gerenciar locações',
    'managed_users'         => 'Usuários gerenciados',
    'name' 					=> 'Nome',
    'nogroup'               => 'Nenhum grupo foi criado ainda. Para criar um, visite: ',
    'notes'                 => 'Notas',
    'password_confirm' 		=> 'Confirmar Senha',
    'password' 				=> 'Senha',
    'phone'  				=> 'Telefone',
    'show_current'          => 'Mostrar Usuários Atuais',
    'show_deleted'          => 'Mostrar Usuários Excluídos',
    'title' 				=> 'Título',
	'to_restore_them'		=> 'para restaurar ele(a).',
    'total_assets_cost'     => "Custo Total de Ativos",
    'updateuser' 			=> 'Atualizar Usuário',
    'username' 				=> 'Usuário',
	'user_deleted_text' 	=> 'Este usuário foi marcado como deletado.',
    'username_note' 		=> '(Istó é usado somente para conexão do Active Directory, não para login.)',
    'cloneuser'             => 'Clonar Usuário',
    'viewusers' 			=> 'Ver Usuários',
);
